@@ -69,9 +69,6 @@
 #include "photos-utils.h"
 
 
-static const gdouble EPSILON = 1e-5;
-
-
 GdkPixbuf *
 photos_utils_center_pixbuf (GdkPixbuf *pixbuf, gint size)
 {
@@ -779,7 +776,7 @@ gboolean
 photos_utils_equal_double (gdouble a, gdouble b)
 {
   const gdouble diff = a - b;
-  return diff > -EPSILON && diff < EPSILON;
+  return diff > -PHOTOS_EPSILON && diff < PHOTOS_EPSILON;
 }
 
 
@@ -1080,20 +1077,18 @@ photos_utils_get_version (void)
 }
 
 
-gboolean
-photos_utils_launch_online_accounts (const gchar *account_id, GError **error)
+void
+photos_utils_launch_online_accounts (const gchar *account_id)
 {
+  GApplication *app;
+  g_autoptr (GDBusActionGroup) control_center = NULL;
+  GDBusConnection *connection;
   GVariant *parameters;
-  g_autoptr (GApplication) control_center = NULL;
   g_auto (GVariantBuilder) panel_parameters = G_VARIANT_BUILDER_INIT (G_VARIANT_TYPE ("av"));
-  gboolean ret_val = FALSE;
-  const gchar *control_center_id = "org.gnome.ControlCenter";
 
-  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
-  control_center = g_application_new (control_center_id, G_APPLICATION_IS_LAUNCHER);
-  if (!g_application_register (control_center, NULL, error))
-    goto out;
+  app = g_application_get_default ();
+  connection = g_application_get_dbus_connection (app);
+  control_center = g_dbus_action_group_get (connection, "org.gnome.ControlCenter", "/org/gnome/ControlCenter");
 
   if (account_id != NULL && account_id[0] != '\0')
     {
@@ -1105,11 +1100,6 @@ photos_utils_launch_online_accounts (const gchar *account_id, GError **error)
 
   parameters = g_variant_new ("(s@av)", "online-accounts", g_variant_builder_end (&panel_parameters));
   g_action_group_activate_action (G_ACTION_GROUP (control_center), "launch-panel", parameters);
-
-  ret_val = TRUE;
-
- out:
-  return ret_val;
 }
 
 
